@@ -1,7 +1,8 @@
 from .dashboard import Dashboard
 from .documents import Documents
 from .return_manager import ReturnManager
+from .files_pending import FilesPending
 
 __all__ = [
-	"Dashboard", "Documents", "ReturnManager"
+	"Dashboard", "Documents", "ReturnManager", "FilesPending"
 ]
