@@ -3,8 +3,11 @@ from .cch_dialog import CchDialog
 
 class ReturnManager(CchDialog):
 	def __init__(self, cch):
-		super(ReturnManager, self).__init__(cch, 'Return Manager')
-
+		super(ReturnManager, self).__init__(
+			cch,
+			title='Return Manager',
+			visible_only=False
+		)
 	def search_by_client_id_or_name(self, search_term):
 		search_input = self.window.child_window(
 			auto_id="clientSearchTextBox"
